﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.DesktopEdition;

namespace WindowsFormsApp1
{
    public partial class Form1 : Form
    {
        private LayerOverlay mobjLayersOverlay;
        private RectangleShape mFullExtent;

        public Form1()
        {
            InitializeComponent();

            mobjLayersOverlay = new LayerOverlay();

            LoadBingMapsLayer();

            winformsMap1.Overlays.Add("Layers", mobjLayersOverlay);
            winformsMap1.MouseWheel += WinformsMap1_MouseWheel;
            winformsMap1.MapUnit = GeographyUnit.Meter;
            winformsMap1.MapResizeMode = MapResizeMode.PreserveExtent;
            winformsMap1.DrawingQuality = DrawingQuality.HighQuality;
            winformsMap1.SmoothingMode = SmoothingMode.HighQuality;
            winformsMap1.CompositingQuality = CompositingQuality.HighSpeed;
            winformsMap1.ExtentOverlay.MouseWheelMode = MapMouseWheelMode.Disabled;
            winformsMap1.ExtentOverlay.RightClickDragMode = MapRightClickDragMode.Disabled;
            winformsMap1.ExtentOverlay.PanMode = MapPanMode.StandardPanning;
            winformsMap1.ZoomLevelSnapping = ZoomLevelSnappingMode.None;
            winformsMap1.CurrentExtent = mFullExtent;
            winformsMap1.Refresh();
        }

        private void WinformsMap1_MouseWheel(object sender, MouseEventArgs e)
        {
            Trace.WriteLine("Wheeling...");

            if (e.Delta < 0) ZoomOut(20);
            else ZoomIn(20);
        }

        private void ZoomIn(int v, PointShape objPoint = null)
        {
            if (objPoint != null) winformsMap1.ZoomIntoCenter(v, objPoint);
            else winformsMap1.ZoomToScale(winformsMap1.CurrentScale / (1 + v * .01));

            winformsMap1.Refresh();
        }

        private void ZoomOut(int v, PointShape objPoint = null)
        {
            if (objPoint != null) winformsMap1.ZoomOutToCenter(v, objPoint);
            else winformsMap1.ZoomToScale(winformsMap1.CurrentScale * (1 + v * .01));

            winformsMap1.Refresh();
        }

        private void LoadBingMapsLayer()
        {
            BingMapsLayer objLayer = new BingMapsLayer("Bing Maps Key", BingMapsMapType.AerialWithLabels, Path.Combine(Application.StartupPath, "Bingmaps"));
            objLayer.TileCache.ClearCache();

            mobjLayersOverlay.Layers.Add("BingMapsLayer", objLayer);
            mobjLayersOverlay.Layers.MoveToBottom("BingMapsLayer");

            mFullExtent = new RectangleShape(-15084380.5844437, 5276411.31850397, -11644096.8502817, 3748285.28774829);
        }
    }
}
